# Artifact Validation Summary

## write_step12_first_draft
- Template: `templates/writing/write_step12_first_draft.yaml`
- Artifact: `test_step12_artifact.md`
- Format: `md`
- Success: ❌
### Checklist
- [pass] meta コメント（HTML）を先頭に含める ()
- [skip] 本文がMarkdownのみで出力されている (handler_not_implemented)
- [skip] 見出しに『# 第{episode_number:03d}話』を含む (handler_not_implemented)
### Metrics
- [fail] unicode_char_count value=579 target=>= 8000
- [pass] kpi_self_check_present value=1 target=>= 1
